Changes
=======

0.2
---

- Change the APIs (An incompatible with older releases)

0.1.2
-----

- Implement the commands execution to make before setup
- Bug fixes

0.1.1
-----

- A few bug fixes

0.1
---

- First release
